<?php
/*
 * Shortcode Parser
 *
 * -------------------------------------
 *
 * @package PB Responsive Images
 * @category Plugin
 * @author Jacob Dunn
 * @link http://www.phenomblue.com/ Phenomblue
 * @version 1.0
 *
 * -------------------------------------
 *
 * Parses shortcodes of either:
 *
 * [RIPImage src="/images/an-image.png" alt="Alt text"]
 *
 * or
 *
 * [RIPImage src="/images/an-image.png" alt="Alt text" ]
 *	 [RIPFormat media="(max-width:100px)" query="w70" fallback="true"]
 *	 [RIPFormat media="(max-width:200px)" query="w170"]
 *	 [RIPFormat media="(max-width:300px)" query="w270"]
 * [/RIPImage]
 *
 * or
 *
 * [RIPImage alt="Alt text" ]
 *	 [RIPSource src="/images/an-image_1.png" media="(max-width:100px)" fallback="true"]
 *	 [RIPSource src="/images/an-image_2.png" media="(max-width:200px)"]
 *	 [RIPSource src="/images/an-image_3.png" media="(max-width:300px)"]
 * [/RIPImage]
 *
 */

class RIPShortcodes{
	public static function register()
	{
		add_shortcode('RIPImage','RIPShortcodes::RIPImage');
		add_shortcode('RIPSource','RIPShortcodes::RIPSource');
		add_shortcode('RIPFormat','RIPShortcodes::RIPFormat');
	}

	public static function RIPImage($attributes, $content = ''){
		$rip = RIP::get_manager();

		if($content === '') return RIP::get_picture($attributes);

		$content = preg_replace('!(<br[^>]*/?>|\n|\r)!','',$content);
		
		if(preg_match('!RIPSource!i', $content)){
			return sprintf('<span data-picture data-alt="%3$s" %1$s>%2$s</span>',
				self::attributes_to_string($attributes,'src,alt'),
				do_shortcode($content),
				$attributes['alt']);
		}else if(preg_match('!RIPFormat!i',$content)){
			$options = '['.rtrim(do_shortcode($content),',').']';
			$options = json_decode($options,true);
			return RIP::get_picture($attributes,$options);
		}

		return sprintf('<pre>%1$s</pre>',$content);//__('Invalid Content passed into RIPImage');
	}

	public static function RIPFormat($attributes, $content = ''){
		return json_encode($attributes).',';
	}

	public static function RIPSource($attributes, $content = ''){
		$attributes = shortcode_atts( array('src' => '','media' => '','fallback'=>false), $attributes);

		$source = sprintf('<span data-src="%1$s" data-media="%2$s"></span>',
			$attributes['src'],
			$attributes['media']);
		if($attributes['fallback'] == true)
			$source .= sprintf('<noscript><image src="%1$s" %2$s></noscript>',
				$attributes['source'],
				self::attributes_to_string($attributes));

		return $source;
	}

	private function attributes_to_string($attributes,$exclude = 'src'){
		$output = array();
		$exclude = explode(',', $exclude);
		foreach ($attributes as $key => $value) {
			if(!in_array($key, $exclude)) array_push($output,sprintf('%1$s="%2$s"',$key,$value));
		}
		return implode(' ', $output);
	}
}

RIPShortcodes::register();